@@ -42,15 +42,15 @@ confint.survtmle <- function(object,
                              parm = seq_along(object$est),
                              level = 0.95,
                              ...) {
-    a <- (1 - level) / 2
-    fac <- stats::qnorm(c(a, 1 - a))
-    pct <- format.perc(c(a, 1 - a), 3)
-    estVec <- object$est[parm]
-    ses <- sqrt(diag(object$var)[parm])
-    ci <- array(NA, dim = c(length(parm), 2L), dimnames = list(parm, pct))
-    ci[] <- estVec + outer(ses, fac)
-    row.names(ci) <- row.names(object$est)[parm]
-    return(ci)
+  a <- (1 - level) / 2
+  fac <- stats::qnorm(c(a, 1 - a))
+  pct <- format.perc(c(a, 1 - a), 3)
+  estVec <- object$est[parm]
+  ses <- sqrt(diag(object$var)[parm])
+  ci <- array(NA, dim = c(length(parm), 2L), dimnames = list(parm, pct))
+  ci[] <- estVec + outer(ses, fac)
+  row.names(ci) <- row.names(object$est)[parm]
+  return(ci)
 }
 
 ################################################################################
@@ -104,40 +104,40 @@ confint.tp.survtmle <- function(object,
                                 parm,
                                 level = 0.95,
                                 ...) {
-    # first, let's get Z <- (1 - alpha)
-    a <- (1 - level) / 2
-    fac <- c(-1, 1) * abs(stats::qnorm(p = a))
+  # first, let's get Z <- (1 - alpha)
+  a <- (1 - level) / 2
+  fac <- c(-1, 1) * abs(stats::qnorm(p = a))
 
-    # extract vectors of point estimates and variance across all timepoints
-    est_allt <- list()
-    ses_allt <- list()
-    for (i in seq_along(object)) {
-        est_allt[[i]] <- object[[i]]$est
-        ses_allt[[i]] <- sqrt(diag(object[[i]]$var))
-    }
+  # extract vectors of point estimates and variance across all timepoints
+  est_allt <- list()
+  ses_allt <- list()
+  for (i in seq_along(object)) {
+    est_allt[[i]] <- object[[i]]$est
+    ses_allt[[i]] <- sqrt(diag(object[[i]]$var))
+  }
 
-    # find number of contrast groups
-    n_grps <- est_allt %>%
-        lapply(., nrow) %>%
-        unique() %>%
-        unlist()
+  # find number of contrast groups
+  n_grps <- est_allt %>%
+    lapply(., nrow) %>%
+    unique() %>%
+    unlist()
 
-    # construct output object and fill across groups
-    ci_tables <- list()
-    for (i in seq_len(n_grps)) {
-        est <- lapply(est_allt, `[[`, i) %>%
-            unlist()
-        ses <- lapply(ses_allt, `[[`, i) %>%
-            unlist() %>%
-            outer(., fac)
-        ci <- est + ses
-        colnames(ci) <- format.perc(c(a, 1 - a), 3)
-        ci_tables[[i]] <- ci
-    }
-    names(ci_tables) <- lapply(est_allt, row.names) %>%
-        unlist() %>%
-        unique()
-    return(ci_tables)
+  # construct output object and fill across groups
+  ci_tables <- list()
+  for (i in seq_len(n_grps)) {
+    est <- lapply(est_allt, `[[`, i) %>%
+      unlist()
+    ses <- lapply(ses_allt, `[[`, i) %>%
+      unlist() %>%
+      outer(., fac)
+    ci <- est + ses
+    colnames(ci) <- format.perc(c(a, 1 - a), 3)
+    ci_tables[[i]] <- ci
+  }
+  names(ci_tables) <- lapply(est_allt, row.names) %>%
+    unlist() %>%
+    unique()
+  return(ci_tables)
 }
 
 ################################################################################
@@ -149,7 +149,9 @@ confint.tp.survtmle <- function(object,
 #' @param probs Probabilities
 #' @param digits Number of digits to round to
 #
-format.perc <- function (probs, digits) {
-    paste(format(100 * probs, trim = TRUE,
-                 scientific = FALSE, digits = digits), "%")
+format.perc <- function(probs, digits) {
+  paste(format(100 * probs,
+    trim = TRUE,
+    scientific = FALSE, digits = digits
+  ), "%")
 }
