@@ -1,5 +1,7 @@
 .onAttach <- function(...) {
   packageStartupMessage("survtmle: Targeted Learning for Survival Analysis")
-  packageStartupMessage("Version: ",
-                        utils::packageDescription("survtmle")$Version)
+  packageStartupMessage(
+    "Version: ",
+    utils::packageDescription("survtmle")$Version
+  )
 }
